@@ -11,8 +11,8 @@ sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from fedex.config import FedexConfig
 
 # Change these values to match your testing account/meter number.
-CONFIG_OBJ = FedexConfig(key='xxxxxxxxxxxxxxxx',
-                         password='xxxxxxxxxxxxxxxxxxxxxxxxx',
-                         account_number='#########',
-                         meter_number='#########',
+CONFIG_OBJ = FedexConfig(key='35khOMxLwlMgovlc',
+                         password='16WukaZdPp9epvFtDgG2tj5eF',
+                         account_number='510087127',
+                         meter_number='118506046',
                          use_test_server=True)
\ No newline at end of file
